@@ -44,15 +44,9 @@ pub(crate) fn segments_setup(
             }
         }
 
-        let mut plot = plots.get_mut(&event.plot_handle).unwrap();
-
-        plot_segments(
-            &mut commands,
-            &mut meshes,
-            // ys,
-            &mut plot,
-            &event.plot_handle,
-        )
+        if let Some(mut plot) = plots.get_mut(&event.plot_handle) {
+            plot_segments(&mut commands, &mut meshes, &mut plot, &event.plot_handle)
+        }
     }
 }
 
@@ -271,7 +265,7 @@ impl FromWorld for SegmentMesh2dPipeline {
         let world = world.cell();
         let asset_server = world.get_resource::<AssetServer>().unwrap();
 
-        let shader_handle = asset_server.load("shaders/segments.wgsl");
+        let shader_handle = asset_server.load("../assets/shaders/segments.wgsl");
 
         Self {
             view_layout: mesh2d_pipeline.view_layout,
